@@ -27,17 +27,18 @@ Architecture:
 
 import contextlib
 import json
-import logging
 import time
 from dataclasses import asdict, dataclass
-from datetime import datetime
+from datetime import datetime, timezone
 from enum import Enum
 from pathlib import Path
 from typing import Any, Dict, List, Optional, Set, Union
 
+from claude_mpm.core.logging_utils import get_logger
+
 from .unified_paths import get_path_manager
 
-logger = logging.getLogger(__name__)
+logger = get_logger(__name__)
 
 
 class AgentTier(Enum):
@@ -460,6 +461,13 @@ class UnifiedAgentRegistry:
             if agent_format == AgentFormat.JSON:
                 data = json.loads(content)
 
+                # Ensure data is a dictionary, not a list
+                if not isinstance(data, dict):
+                    logger.warning(
+                        f"Invalid JSON structure in {file_path}: expected object, got {type(data).__name__}"
+                    )
+                    return "", []
+
                 # Handle local agent JSON templates with metadata structure
                 if "metadata" in data:
                     metadata = data["metadata"]
@@ -711,7 +719,7 @@ class UnifiedAgentRegistry:
 
         export_data = {
             "metadata": {
-                "export_time": datetime.now().isoformat(),
+                "export_time": datetime.now(timezone.utc).isoformat(),
                 "total_agents": len(self.registry),
                 "discovery_paths": [str(p) for p in self.discovery_paths],
             },
