@@ -21,10 +21,9 @@ multi-file implementation for better maintainability.
 
 import asyncio
 import json
-import logging
 import os
 from dataclasses import dataclass, field
-from datetime import datetime
+from datetime import datetime, timezone
 from enum import Enum
 from pathlib import Path
 from typing import Any, Dict, List, Optional, Tuple
@@ -33,11 +32,12 @@ import yaml
 
 from claude_mpm.core.base_service import BaseService
 from claude_mpm.core.config import Config
+from claude_mpm.core.logging_utils import get_logger
 from claude_mpm.core.unified_paths import get_path_manager
 from claude_mpm.services.agents.registry import AgentRegistry
 from claude_mpm.services.memory.cache.shared_prompt_cache import SharedPromptCache
 
-logger = logging.getLogger(__name__)
+logger = get_logger(__name__)
 
 # ============================================================================
 # Data Models
@@ -227,7 +227,9 @@ class AgentProfileLoader(BaseService):
         # Check cache first
         if use_cache and agent_name in self.profile_cache:
             profile = self.profile_cache[agent_name]
-            if (datetime.now() - profile.loaded_at).seconds < self.cache_ttl:
+            if (
+                datetime.now(timezone.utc) - profile.loaded_at
+            ).seconds < self.cache_ttl:
                 self.load_metrics[f"{agent_name}_cache_hit"] = (
                     asyncio.get_event_loop().time() - start_time
                 )
@@ -322,7 +324,7 @@ class AgentProfileLoader(BaseService):
                 try:
                     data = yaml.safe_load(content)
                     instructions = data.get("instructions", "")
-                except:
+                except Exception:
                     data = json.loads(content)
                     instructions = data.get("instructions", "")
 
