@@ -10,6 +10,7 @@ import subprocess
 from pathlib import Path
 from typing import Dict, List, Optional, Tuple
 
+from claude_mpm.core.logger import get_logger
 from ..models import DiagnosticResult, DiagnosticStatus
 from .base_check import BaseDiagnosticCheck
 
@@ -17,6 +18,11 @@ from .base_check import BaseDiagnosticCheck
 class MCPServicesCheck(BaseDiagnosticCheck):
     """Check MCP external services installation and health."""
 
+    def __init__(self, verbose: bool = False):
+        """Initialize the MCP services check."""
+        super().__init__(verbose)
+        self.logger = get_logger(self.__class__.__name__)
+
     # Define MCP services to check
     MCP_SERVICES = {
         "mcp-vector-search": {
@@ -71,6 +77,11 @@ class MCPServicesCheck(BaseDiagnosticCheck):
             sub_results = []
             services_status = {}
 
+            # Check for kuzu-memory configuration issues and offer auto-fix
+            kuzu_config_result = self._check_and_fix_kuzu_memory_config()
+            if kuzu_config_result:
+                sub_results.append(kuzu_config_result)
+
             # Check each MCP service
             for service_name, service_config in self.MCP_SERVICES.items():
                 service_result = self._check_service(service_name, service_config)
@@ -391,6 +402,117 @@ class MCPServicesCheck(BaseDiagnosticCheck):
 
         return None
 
+    def _check_and_fix_kuzu_memory_config(self) -> Optional[DiagnosticResult]:
+        """Check for incorrect kuzu-memory configuration in .claude.json and offer auto-fix."""
+        claude_config_path = Path.home() / ".claude.json"
+
+        if not claude_config_path.exists():
+            return None
+
+        try:
+            with open(claude_config_path) as f:
+                config = json.load(f)
+
+            mcp_servers = config.get("mcpServers", {})
+            kuzu_config = mcp_servers.get("kuzu-memory")
+
+            if not kuzu_config:
+                return None
+
+            # Check if kuzu-memory has incorrect args
+            args = kuzu_config.get("args", [])
+            needs_fix = False
+            fix_reason = ""
+            new_args = None
+
+            # Check for outdated configurations
+            if args == ["claude", "mcp-server"]:
+                needs_fix = True
+                fix_reason = "Outdated 'claude mcp-server' format"
+                new_args = ["mcp", "serve"]
+            elif args == ["serve"]:
+                needs_fix = True
+                fix_reason = "Legacy 'serve' format"
+                new_args = ["mcp", "serve"]
+            elif args == ["mcp-server"]:
+                needs_fix = True
+                fix_reason = "Incorrect 'mcp-server' format"
+                new_args = ["mcp", "serve"]
+
+            if needs_fix:
+                # Offer to auto-fix
+                self.logger.warning(
+                    f"Found incorrect kuzu-memory configuration: {fix_reason}. "
+                    f"Current args: {args}"
+                )
+
+                # Auto-fix the configuration
+                fixed = self._fix_kuzu_memory_args(claude_config_path, config, new_args)
+
+                if fixed:
+                    return DiagnosticResult(
+                        category="kuzu-memory Configuration Fix",
+                        status=DiagnosticStatus.OK,
+                        message="Fixed kuzu-memory configuration",
+                        details={
+                            "old_args": args,
+                            "new_args": new_args,
+                            "reason": fix_reason,
+                            "auto_fixed": True,
+                        },
+                    )
+                else:
+                    return DiagnosticResult(
+                        category="kuzu-memory Configuration",
+                        status=DiagnosticStatus.WARNING,
+                        message="kuzu-memory has incorrect configuration",
+                        details={
+                            "current_args": args,
+                            "correct_args": new_args,
+                            "reason": fix_reason,
+                            "auto_fix_failed": True,
+                        },
+                        fix_command="claude-mpm configure --mcp --fix-kuzu",
+                        fix_description="Fix kuzu-memory configuration manually",
+                    )
+
+            # Configuration is correct
+            return None
+
+        except (json.JSONDecodeError, Exception) as e:
+            self.logger.debug(f"Could not check kuzu-memory config: {e}")
+            return None
+
+    def _fix_kuzu_memory_args(self, config_path: Path, config: Dict, new_args: List[str]) -> bool:
+        """Fix kuzu-memory args in the configuration."""
+        try:
+            # Save old args before updating
+            old_args = config["mcpServers"]["kuzu-memory"].get("args", [])
+
+            # Create backup
+            backup_path = config_path.with_suffix(".json.backup")
+            with open(backup_path, "w") as f:
+                json.dump(config, f, indent=2)
+
+            # Update the configuration
+            config["mcpServers"]["kuzu-memory"]["args"] = new_args
+
+            # Write updated configuration
+            with open(config_path, "w") as f:
+                json.dump(config, f, indent=2)
+
+            self.logger.info(
+                f"✅ Fixed kuzu-memory configuration in {config_path}\n"
+                f"   Changed args from {old_args} to {new_args}\n"
+                f"   Backup saved to {backup_path}"
+            )
+
+            return True
+
+        except Exception as e:
+            self.logger.error(f"Failed to fix kuzu-memory configuration: {e}")
+            return False
+
     def _check_gateway_configuration(self) -> DiagnosticResult:
         """Check if MCP services are configured in the gateway."""
         try:
