@@ -18,15 +18,14 @@ DESIGN DECISIONS:
 - Handles agent name normalization for consistent tracking
 """
 
-import logging
-from datetime import datetime
+from datetime import datetime, timezone
 from typing import Any, Dict, Optional
 
 from claude_mpm.core.config import Config
+from claude_mpm.core.logging_utils import get_logger
 from claude_mpm.core.shared.config_loader import ConfigLoader
-from claude_mpm.services.claude_session_logger import ClaudeSessionLogger
 
-logger = logging.getLogger(__name__)
+logger = get_logger(__name__)
 
 
 class ResponseTracker:
@@ -145,7 +144,7 @@ class ResponseTracker:
             {
                 "agent": agent_name,
                 "tracked_by": "ResponseTracker",
-                "tracking_timestamp": datetime.now().isoformat(),
+                "tracking_timestamp": datetime.now(timezone.utc).isoformat(),
             }
         )
 
