@@ -13,7 +13,7 @@ import asyncio
 import threading
 import time
 from collections import deque
-from datetime import datetime
+from datetime import datetime, timezone
 from typing import Any, Dict, List, Optional, Set
 
 try:
@@ -35,6 +35,7 @@ from ....core.logging_config import get_logger
 from ...core.interfaces.communication import SocketIOServiceInterface
 from ..handlers import EventHandlerRegistry, FileEventHandler, GitEventHandler
 from .broadcaster import SocketIOEventBroadcaster
+from .connection_manager import ConnectionManager
 from .core import SocketIOServerCore
 from .eventbus_integration import EventBusIntegration
 
@@ -91,6 +92,9 @@ class SocketIOServer(SocketIOServiceInterface):
         # EventBus integration
         self.eventbus_integration = None
 
+        # Connection manager for robust connection tracking
+        self.connection_manager = None
+
     def start_sync(self):
         """Start the Socket.IO server in a background thread (synchronous version)."""
         if not SOCKETIO_AVAILABLE:
@@ -103,14 +107,21 @@ class SocketIOServer(SocketIOServiceInterface):
         # Debug logging for EventBus initialization
         self.logger.info("Starting Socket.IO server with EventBus integration...")
         print(
-            f"[{datetime.now().isoformat()}] SocketIOServer.start_sync() called",
+            f"[{datetime.now(timezone.utc).isoformat()}] SocketIOServer.start_sync() called",
             flush=True,
         )
 
-        # Start the core server
+        # CRITICAL: Start the core server first to create sio instance
+        # Event handlers will be registered inside _start_server before accepting connections
         self.core.start_sync()
 
-        # Initialize broadcaster with core server components
+        # Initialize connection manager for robust connection tracking
+        self.connection_manager = ConnectionManager(
+            max_buffer_size=getattr(SystemLimits, "MAX_EVENTS_BUFFER", 1000),
+            event_ttl=300,  # 5 minutes TTL for buffered events
+        )
+
+        # Initialize broadcaster with core server components and connection manager
         self.broadcaster = SocketIOEventBroadcaster(
             sio=self.core.sio,
             connected_clients=self.connected_clients,
@@ -119,6 +130,7 @@ class SocketIOServer(SocketIOServiceInterface):
             stats=self.stats,
             logger=self.logger,
             server=self,  # Pass server reference for event history access
+            connection_manager=self.connection_manager,  # Pass connection manager
         )
 
         # Wait for the event loop to be initialized in the background thread
@@ -146,45 +158,81 @@ class SocketIOServer(SocketIOServiceInterface):
             # Start the retry processor for resilient event delivery
             self.broadcaster.start_retry_processor()
 
-        # Register events
-        self._register_events()
+            # Start connection health monitoring
+            if self.connection_manager:
+                asyncio.run_coroutine_threadsafe(
+                    self.connection_manager.start_health_monitoring(), self.core.loop
+                )
+
+        # Register events if not already done in async context
+        if self.core.sio and not self.event_registry:
+            self._register_events()
 
         # Setup EventBus integration
         # WHY: This connects the EventBus to the Socket.IO server, allowing
         # events from other parts of the system to be broadcast to dashboard
         print(
-            f"[{datetime.now().isoformat()}] Setting up EventBus integration...",
+            f"[{datetime.now(timezone.utc).isoformat()}] Setting up EventBus integration...",
             flush=True,
         )
-        try:
-            self.eventbus_integration = EventBusIntegration(self)
+
+        # CRITICAL: Ensure broadcaster is fully initialized before setting up EventBus
+        # The relay needs the broadcaster to be ready to relay events
+        if not self.broadcaster:
+            self.logger.error(
+                "Broadcaster not initialized - cannot setup EventBus integration"
+            )
             print(
-                f"[{datetime.now().isoformat()}] EventBusIntegration instance created",
+                f"[{datetime.now(timezone.utc).isoformat()}] ERROR: Broadcaster not initialized",
+                flush=True,
+            )
+        else:
+            print(
+                f"[{datetime.now(timezone.utc).isoformat()}] Broadcaster ready, proceeding with EventBus setup",
                 flush=True,
             )
 
-            if self.eventbus_integration.setup(self.port):
-                self.logger.info("EventBus integration setup successful")
+            try:
+                self.eventbus_integration = EventBusIntegration(self)
                 print(
-                    f"[{datetime.now().isoformat()}] EventBus integration setup successful",
+                    f"[{datetime.now(timezone.utc).isoformat()}] EventBusIntegration instance created",
                     flush=True,
                 )
-            else:
-                self.logger.warning("EventBus integration setup failed or disabled")
-                print(
-                    f"[{datetime.now().isoformat()}] EventBus integration setup failed or disabled",
-                    flush=True,
-                )
-        except Exception as e:
-            self.logger.error(f"Failed to setup EventBus integration: {e}")
-            print(
-                f"[{datetime.now().isoformat()}] Failed to setup EventBus integration: {e}",
-                flush=True,
-            )
-            import traceback
 
-            traceback.print_exc()
-            self.eventbus_integration = None
+                if self.eventbus_integration.setup(self.port):
+                    self.logger.info("EventBus integration setup successful")
+                    print(
+                        f"[{datetime.now(timezone.utc).isoformat()}] EventBus integration setup successful",
+                        flush=True,
+                    )
+
+                    # Verify relay is connected and has broadcaster
+                    if (
+                        hasattr(self.eventbus_integration, "relay")
+                        and self.eventbus_integration.relay
+                    ):
+                        relay_stats = self.eventbus_integration.relay.get_stats()
+                        self.logger.info(f"EventBus relay stats: {relay_stats}")
+                        print(
+                            f"[{datetime.now(timezone.utc).isoformat()}] EventBus relay stats: {relay_stats}",
+                            flush=True,
+                        )
+                else:
+                    self.logger.warning("EventBus integration setup failed or disabled")
+                    print(
+                        f"[{datetime.now(timezone.utc).isoformat()}] EventBus integration setup failed or disabled",
+                        flush=True,
+                    )
+            except Exception as e:
+                self.logger.error(f"Failed to setup EventBus integration: {e}")
+                print(
+                    f"[{datetime.now(timezone.utc).isoformat()}] Failed to setup EventBus integration: {e}",
+                    flush=True,
+                )
+                import traceback
+
+                traceback.print_exc()
+                self.eventbus_integration = None
 
         # Update running state
         self.running = self.core.running
@@ -200,6 +248,15 @@ class SocketIOServer(SocketIOServiceInterface):
         if self.broadcaster:
             self.broadcaster.stop_retry_processor()
 
+        # Stop connection health monitoring
+        if self.connection_manager and self.core.loop:
+            try:
+                asyncio.run_coroutine_threadsafe(
+                    self.connection_manager.stop_health_monitoring(), self.core.loop
+                ).result(timeout=2)
+            except Exception as e:
+                self.logger.warning(f"Error stopping health monitoring: {e}")
+
         # Teardown EventBus integration
         if self.eventbus_integration:
             try:
@@ -208,10 +265,16 @@ class SocketIOServer(SocketIOServiceInterface):
             except Exception as e:
                 self.logger.error(f"Error during EventBus teardown: {e}")
 
-        # Stop health monitoring in connection handler
+        # Stop code analysis handler
         if self.event_registry:
-            from ..handlers import ConnectionEventHandler
+            from ..handlers import CodeAnalysisEventHandler, ConnectionEventHandler
 
+            # Stop analysis runner
+            analysis_handler = self.event_registry.get_handler(CodeAnalysisEventHandler)
+            if analysis_handler and hasattr(analysis_handler, "cleanup"):
+                analysis_handler.cleanup()
+
+            # Stop health monitoring in connection handler
             conn_handler = self.event_registry.get_handler(ConnectionEventHandler)
             if conn_handler and hasattr(conn_handler, "stop_health_monitoring"):
                 conn_handler.stop_health_monitoring()
@@ -226,6 +289,12 @@ class SocketIOServer(SocketIOServiceInterface):
         handlers in a modular way. Each handler focuses on a specific domain,
         reducing complexity and improving maintainability.
         """
+        if not self.core.sio:
+            self.logger.error(
+                "Cannot register events - Socket.IO server not initialized"
+            )
+            return
+
         # Initialize the event handler registry
         self.event_registry = EventHandlerRegistry(self)
         self.event_registry.initialize()
@@ -239,6 +308,31 @@ class SocketIOServer(SocketIOServiceInterface):
 
         self.logger.info("All Socket.IO events registered via handler system")
 
+    async def _register_events_async(self):
+        """Async version of event registration for calling from async context.
+
+        WHY: This allows us to register events from within the async _start_server
+        method before the server starts accepting connections.
+        """
+        if not self.core.sio:
+            self.logger.error(
+                "Cannot register events - Socket.IO server not initialized"
+            )
+            return
+
+        # Initialize the event handler registry
+        self.event_registry = EventHandlerRegistry(self)
+        self.event_registry.initialize()
+
+        # Register all events from all handlers
+        self.event_registry.register_all_events()
+
+        # Keep handler instances for HTTP endpoint compatibility
+        self.file_handler = self.event_registry.get_handler(FileEventHandler)
+        self.git_handler = self.event_registry.get_handler(GitEventHandler)
+
+        self.logger.info("All Socket.IO events registered via handler system (async)")
+
     # Delegate broadcasting methods to the broadcaster
     def broadcast_event(self, event_type: str, data: Dict[str, Any]):
         """Broadcast an event to all connected clients."""
@@ -288,7 +382,7 @@ class SocketIOServer(SocketIOServiceInterface):
         # Track active session for heartbeat
         self.active_sessions[session_id] = {
             "session_id": session_id,
-            "start_time": datetime.now().isoformat(),
+            "start_time": datetime.now(timezone.utc).isoformat(),
             "agent": "pm",  # Default to PM, will be updated if delegated
             "status": "active",
             "launch_method": launch_method,
@@ -378,7 +472,7 @@ class SocketIOServer(SocketIOServiceInterface):
         WHY: Provides session information for system heartbeat events.
         """
         # Clean up old sessions (older than 1 hour)
-        cutoff_time = datetime.now().timestamp() - 3600
+        cutoff_time = datetime.now(timezone.utc).timestamp() - 3600
         sessions_to_remove = []
 
         for session_id, session_data in self.active_sessions.items():
@@ -386,7 +480,7 @@ class SocketIOServer(SocketIOServiceInterface):
                 start_time = datetime.fromisoformat(session_data["start_time"])
                 if start_time.timestamp() < cutoff_time:
                     sessions_to_remove.append(session_id)
-            except:
+            except Exception:
                 pass
 
         for session_id in sessions_to_remove:
